@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 
+import re
 import os
 import sys
 import glob
@@ -9,9 +10,10 @@ from werkzeug.utils import import_string
 
 
 def load_resources(module_names):
-    """Import all modules in `module_names` to load resources.
+    """Import all modules in ``module_names`` to load resources.
+
+    Example usage::
 
-    Example usage:
         load_resources(['yourapi.resources.users.resource'])
         load_resources(['yourapi.resources.orders.resource'])
 
@@ -32,9 +34,10 @@ def load_resources(module_names):
 
 
 def expand_wildcards(module_name):
-    """Expand the wildcards in `module_name` based on `sys.path`.
+    """Expand the wildcards in ``module_name`` based on ``sys.path``.
+
+    Suppose the directory structure of "yourapi" is as below::
 
-    Suppose the directory structure of "yourapi" is as below:
         yourapi
         |-- __init__.py
         `-- resources
@@ -44,7 +47,9 @@ def expand_wildcards(module_name):
             `-- orders
                 |-- __init__.py
                 `-- resource.py
-    Then:
+
+    Then::
+
         expand_wildcards('yourapi.resources.*.resource')
         =>
         ['yourapi.resources.users.resource',
@@ -61,9 +66,8 @@ def expand_wildcards(module_name):
 
     modnames = []
     for pyfile in pyfiles:
-        relpath = pyfile[len(basedir) + 1:]
-        modpath = relpath.rstrip('/__init__.py')
-        modpath = modpath.rstrip('.py')
+        relpath = pyfile[len(basedir) + 1:] if basedir else pyfile
+        modpath = re.sub('(/__init__)?\.py$', '', relpath)
         modname = modpath.replace('/', '.')
         modnames.append(modname)
     return modnames
@@ -78,7 +82,12 @@ class locked_cached_property(object):
 
     This decorator has a lock for thread safety.
 
-    Inspired by `Flask`.
+    Inspired by ``Flask``.
+
+    :param method: the method that will be decorated.
+    :param name: the name of the cached property, which holds the
+                 calculated result. If not specified, the ``<method-name>``
+                 (the name of the decorated method) will be used.
     """
 
     # sentinel
@@ -124,15 +133,21 @@ class classproperty(property):
 
 
 class locked_cached_classproperty(locked_cached_property):
-    """The lazy version of classproperty, like `locked_cached_property`.
-    """
+    """The lazy version of ``classproperty``, which converts a method into
+    a lazy class property.
 
-    def __init__(self, method=None, name=None):
-        super(locked_cached_classproperty, self).__init__(method, name)
+    :param method: the method that will be decorated.
+    :param name: the name of the cached class property, which holds the
+                 calculated result. If not specified, the name with the
+                 form of ``_locked_cached_classproperty_<method-name>``
+                 will be used.
+    """
 
     def __call__(self, method):
         self.method = classproperty(method)
-        self.name = self.name or method.__name__
+        self.name = self.name or (
+            '_%s_%s' % (self.__class__.__name__, method.__name__)
+        )
         return self
 
     def __get__(self, obj, cls):
@@ -140,6 +155,10 @@ class locked_cached_classproperty(locked_cached_property):
             value = cls.__dict__.get(self.name, self._missing)
             if value is self._missing:
                 value = self.method.__get__(obj, cls)
+                # In new-style classes, class.__dict__ is of type
+                # `dict_proxy`, which can only be modified by `setattr`
+                # (instead of `class.__dict__[key] = value`).
+                # See http://stackoverflow.com/questions/432786/how-can-i-assign-a-new-class-attribute-via-dict-in-python
                 setattr(cls, self.name, value)
             return value
 
